Breezy User Guide — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# Breezy User Guide

## Introduction

- Introducing Breezy
- Core concepts
- Workflows

## Getting started

- Installing Breezy
- Entering commands
- Getting help
- Configuring Breezy
- Using aliases
- Using plugins
- Breezy Zen

## Personal version control

- Going solo
- Starting a project
- Controlling file registration
- Reviewing changes
- Recording changes
- Browsing history
- Releasing a project
- Undoing mistakes

## Sharing with peers

- Working with another
- Branching a project
- Merging changes
- Resolving conflicts
- Annotating changes

## Team collaboration, central style

- Centralized development
- Publishing a branch
- Using checkouts
- Working offline on a central branch
- Reusing a checkout

## Team collaboration, distributed style

- Distributed development
- Organizing branches
- Using gatekeepers
- Sending changes

## Miscellaneous topics

- The journey ahead
- Pseudo merging
- Switch –store
- Shelving Changes
- Filtered views
- Using stacked branches
- Running a smart server
- Using hooks
- Exporting version information
- GnuPG Signatures

## A brief tour of some popular plugins

- brz-svn

## Integrating Breezy into your environment

- Web browsing
- Bug trackers

## Appendices

- Specifying revisions
- Organizing your workspace
- Advanced shared repository layouts
- Configuring email
- Serving Breezy with Apache
- Writing a plugin
- Licence